@@ -2,11 +2,7 @@
 #include <fstream>
 #include <algorithm>
 #include <limits>
-#include "mlocate_db.h"
-//       original filename is 'db.h'
-// TODO: should be packaged in /usr/include by 'mlocate' package
-//       like 'make' provides '/usr/include/gnumake.h'
-//       and  'sudo' provides '/usr/include/sudo_plugin.h'
+#include <mlocate/db.h>
 
 #include "mlocate.h"
 
@@ -75,7 +71,6 @@ int read_mlocate(vector<string>& fs, vector<string>& prunefs)
 		    or (toplevel == "/home" and dirname != "/home")
 		    or toplevel == "/mnt"
 		    or toplevel == "/root"
-		    or toplevel == "/srv"
 		    or toplevel == "/tmp")
 		while ((mlocate.get()) != DBE_END) {
 			mlocate.ignore(std::numeric_limits<int>::max(), '\0');
